@@ -222,6 +222,22 @@ class UseTestCase(unittest.TestCase):
         job.hour.on(1)
         self.assertEqual(str(job), '5 1 * * * cmd')
 
+    def test_09_pre_comment(self):
+        """Test use of pre_comments"""
+        text = """
+# Unattached comment
+
+5 * * * 6 some_command
+# Attached comment
+*/5 * * * * another_command
+*/5 * * * * my_command # Other comment
+"""
+        tab = crontab.CronTab(tab=text)
+        self.assertEqual(tab[0].comment, "")
+        self.assertEqual(tab[1].comment, "Attached comment")
+        self.assertEqual(tab[2].comment, "Other comment")
+        self.assertEqual(tab.render(), text)
+
     def tearDown(self):
         for filename in self.filenames:
             if os.path.exists(filename):
